@@ -487,7 +487,7 @@ bool KSldApp::establishGrab()
     qCDebug(KSCREENLOCKER) << "Establishing grab";
 
     if (m_isWayland) {
-        return m_waylandFd >= 0;
+        return true;
     }
     if (!m_isX11) {
         return true;
@@ -635,6 +635,8 @@ void KSldApp::startLockProcess(EstablishLock establishLock)
 {
     qCDebug(KSCREENLOCKER) << "Starting lock process with establishLock:" << establishLockToString(establishLock);
 
+    Q_EMIT aboutToStartGreeter();
+
     QProcessEnvironment env = m_greeterEnv;
 
     if (m_isWayland && m_waylandFd >= 0) {
